import { 
  select, 
  csv, 
  scaleLinear, 
  scalePoint, 
  max,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const title = "Gender Pay Gap";
  
  const xValue = d => d.womenAvg;
	const xAxisLabel = 'Year Salary';
  
  const x2Value = d => d.menAvg;
  const yValue = d => d.title; 
  
  const margin = {top: 50, right: 40, bottom: 75, left: 250};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, x2Value)])
  	.range([0, innerWidth])
  	.rangeRound([40, innerWidth - 40]);
  
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	//.rangeRound([innerHeight, 10])
  	.padding(0.9);
  
  const chart = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  // x-axis
  const xAxis = axisBottom(xScale)
  	.tickFormat(format('$.2s'))
  	.ticks(5);
  
  const xAxisG = chart.append("g")
  	.call(xAxis)
      .attr("class", "x-axis")  
  		.attr('transform', `translate(0, ${innerHeight})`);

  // y-axis
  chart.append("g")
      .call(d3.axisLeft(yScale))
      .attr("class", "y axis")
  		.selectAll('.domain, .tick line').remove();
  
  const dumbbellGroup = chart.append("g")
      .attr("id", "dumbbellGroup");
  
  const dumbbell = dumbbellGroup
  	.selectAll(".dumbbell")
      .data(data)
    .enter().append("g")
      .attr("class", "dumbbell")
  		.attr("transform", d => `translate(0, ${yScale(yValue(d))})`);
  
  // lines: between dots
  dumbbell
    .append("line")
      .attr("class", "line-between")
      .attr("x1", function(d) { return xScale(xValue(d)); })
      .attr("x2", function(d) { return xScale(x2Value(d)); })
      .attr("y1", 0)
      .attr("y2", 0);
  
  dumbbell
    .append("line")
      .attr("class", "line-before")
      .attr("x1", 0)
      .attr("x2", function(d) { return xScale(xValue(d)); })
      .attr("y1", 0)
      .attr("y2", 0);
  
  // dots: current inventory
  dumbbell.append("circle")
      .attr("class", "circle-before")
      .attr("cx", function(d) { return xScale(xValue(d)); })
      .attr("cy", 0)
      .attr("r", 6);
  
    // dots: current inventory
  dumbbell
    .append("circle")
      .attr("class", "circle-after")
      .attr("cx", function(d) { return xScale(x2Value(d)); })
      .attr("cy", 0)
      .attr("r", 6);
  
  const formatPlotNumbers = (d, xData) => 
  	format(',.4r')(xData(d))
  	.replace('.0', '');
  
  // data labels: current
  dumbbell
    .append("text")
      .attr("class", "text-before")
  		.attr('x', d => xScale(xValue(d)) - 20)
  		.attr('text-anchor', 'end')
      .attr("y", 0)
      .attr("dy", ".35em")
      .attr("dx", 10)
  		.text(d => formatPlotNumbers(d, xValue));
  
   // data labels: future
  dumbbell
    .append("text")
      .attr("class", "text-future")
      .attr("x", function(d) { return xScale(x2Value(d)) + 75; })
      .attr("y", 0)
      .attr("dy", ".35em")
      .attr("dx", -10)
      .attr("text-anchor", "end")
  		.text(d => formatPlotNumbers(d, x2Value));
  
  chart
    .append('text')
      .text(title)
      .attr('class', 'title')
      .attr('x', innerWidth / 2)
      .attr('text-anchor', 'middle');
  
  xAxisG
    .append('text')
      .text(xAxisLabel)
      .attr('class', 'xAxisLabel')
      .attr('x', innerWidth / 2)
      .attr('y', 65)
      .attr('text-anchor', 'middle');
  
}


csv('data.csv').then(data => {
	data.forEach(d => {
  	d.womenAvg = +d.womenAvg;
    d.menAvg = +d.menAvg;
    })
  console.log(data);
  const excluded = ['Health Technicians'];
  data = data.filter(d => {
  	return excluded.indexOf(d.title) == -1;
  });
  render(data);
});


























